

BEGIN {
  $Module::CPANTS::Site::USER='cpants';
  $Module::CPANTS::Site::PWD='c028m11';
}

use lib qw(
    /home/domm/myperl/lib
    /home/domm/Module-CPANTS-Analyse/lib
    /home/domm/Module-CPANTS-ProcessCPAN/lib
    /home/domm/Module-CPANTS-Site/lib
);

use Module::CPANTS::Site;

1;

