package Module::CPANTS::Site::Model::Kwalitee;
use strict;
use warnings;
use Module::CPANTS::Kwalitee;

our $KW=Module::CPANTS::Kwalitee->new;

sub kwalitee { return $KW }



'listeing to: kids during judo training';

__END__
